Routers/quick_router_transitions library

Classes

QuickFade
Fade transition: Changing the opacity of the screen during the transition.
QuickRotate
Rotate transition: Rotating the screen during the transition.
QuickScale
Scale transition: Scaling the screen during the transition.
QuickSize
Size transition: Changing the size of the screen during the transition.
QuickSlide
Slide transition: Moving the screen in from the side.
QuickTransition<T>
QuickTransition is a class providing quick implementations of various transition animations for routing between screens.