QuickFade class

Fade transition: Changing the opacity of the screen during the transition.

Inheritance

Constructors

QuickFade({Animation<double>? opacity, bool alwaysIncludeSemantics = false, Duration transitionDuration = const Duration(milliseconds: 100), Duration reverseTransitionDuration = const Duration(milliseconds: 100), bool opaque = true, bool barrierDismissible = false, Color? barrierColor, String? barrierLabel, bool maintainState = true, bool fullscreenDialog = false, bool allowSnapshotting = true})
const

Properties

allowSnapshotting bool
finalinherited
alwaysIncludeSemantics bool
final
barrierColor Color?
finalinherited
barrierDismissible bool
finalinherited
barrierLabel String?
finalinherited
fullscreenDialog bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maintainState bool
finalinherited
opacity Animation<double>?
final
opaque bool
finalinherited
reverseTransitionDuration Duration
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionDuration Duration
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited