QuickScale class

Scale transition: Scaling the screen during the transition.

Inheritance

Constructors

QuickScale({Animation<double>? scale, Alignment? alignment, FilterQuality? filterQuality, Duration transitionDuration = const Duration(milliseconds: 100), Duration reverseTransitionDuration = const Duration(milliseconds: 100), bool opaque = true, bool barrierDismissible = false, Color? barrierColor, String? barrierLabel, bool maintainState = true, bool fullscreenDialog = false, bool allowSnapshotting = true})
const

Properties

alignment Alignment?
final
allowSnapshotting bool
finalinherited
barrierColor Color?
finalinherited
barrierDismissible bool
finalinherited
barrierLabel String?
finalinherited
filterQuality FilterQuality?
final
fullscreenDialog bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maintainState bool
finalinherited
opaque bool
finalinherited
reverseTransitionDuration Duration
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale Animation<double>?
final
transitionDuration Duration
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited