QuickSize class

Size transition: Changing the size of the screen during the transition.

Inheritance

Constructors

QuickSize({Animation<double>? sizeFactor, double? fixedCrossAxisSizeFactor, double? axisAlignment, Axis? axis, Duration transitionDuration = const Duration(milliseconds: 100), Duration reverseTransitionDuration = const Duration(milliseconds: 100), bool opaque = true, bool barrierDismissible = false, Color? barrierColor, String? barrierLabel, bool maintainState = true, bool fullscreenDialog = false, bool allowSnapshotting = true})
const

Properties

allowSnapshotting bool
finalinherited
axis Axis?
final
axisAlignment double?
final
barrierColor Color?
finalinherited
barrierDismissible bool
finalinherited
barrierLabel String?
finalinherited
fixedCrossAxisSizeFactor double?
final
fullscreenDialog bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maintainState bool
finalinherited
opaque bool
finalinherited
reverseTransitionDuration Duration
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeFactor Animation<double>?
final
transitionDuration Duration
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited