QuickSlide class

Slide transition: Moving the screen in from the side.

Inheritance

Constructors

QuickSlide({Offset? start, Offset? end, Animatable<double>? animate, bool transformHitTests = false, TextDirection? textDirection, Duration transitionDuration = const Duration(milliseconds: 100), Duration reverseTransitionDuration = const Duration(milliseconds: 100), bool opaque = true, bool barrierDismissible = false, Color? barrierColor, String? barrierLabel, bool maintainState = true, bool fullscreenDialog = false, bool allowSnapshotting = true})
const

Properties

allowSnapshotting bool
finalinherited
animate Animatable<double>?
Default Value is: CurveTween(curve: Curves.easeInOut)
final
barrierColor Color?
finalinherited
barrierDismissible bool
finalinherited
barrierLabel String?
finalinherited
end Offset?
final
fullscreenDialog bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maintainState bool
finalinherited
opaque bool
finalinherited
reverseTransitionDuration Duration
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Offset?
final
textDirection TextDirection?
final
transformHitTests bool
final
transitionDuration Duration
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited