Routers/quick_routes library

Extensions

QuickRouters on BuildContext
An extension that provides some handy methods for navigating between routes using the Navigator widget. It supports both regular and restorable routes, as well as different transition types.