removeRoute method
A method that removes the given route from the Navigator.
Implementation
void removeRoute(Route<dynamic> route) {
return Navigator.of(this).removeRoute(route);
}
A method that removes the given route from the Navigator.
void removeRoute(Route<dynamic> route) {
return Navigator.of(this).removeRoute(route);
}