removeRouteBelow method
A method that removes the route below the given one from the Navigator.
Implementation
void removeRouteBelow(Route<dynamic> anchorRoute) {
return Navigator.of(this).removeRouteBelow(anchorRoute);
}
A method that removes the route below the given one from the Navigator.
void removeRouteBelow(Route<dynamic> anchorRoute) {
return Navigator.of(this).removeRouteBelow(anchorRoute);
}