QuickNamedRoute class

Defines a named route that can be used with MaterialApp.routes or MaterialApp.onGenerateRoute.

Constructors

QuickNamedRoute({required String name, required QuickRouteWidgetBuilder builder, QuickTransition? transitions})
const

Properties

builder QuickRouteWidgetBuilder
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitions QuickTransition?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited