QuickRouter class

Constructors

QuickRouter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

builder<T>(Widget child, QuickTransition? transitions, {RouteSettings? settings}) PageRouteBuilder<T>
defaultTransition<T>(Widget child, {RouteSettings? settings}) PageRouteBuilder<T>
named<T extends Object?>(QuickNamedRoute route, {Object? arguments, RouteSettings? settings}) Route<T>
onGenerateRoute(Iterable<QuickNamedRoute> routes) RouteFactory
routes(Iterable<QuickNamedRoute> routes) Map<String, WidgetBuilder>