Routers/quick_routes library

Classes

MyAppRoutes

Extensions

QuickRouters on BuildContext
An extension that provides some handy methods for navigating between routes using the Navigator widget. It supports both regular and restorable routes, named routes, and different transition types.